================
Generator Config
================

The configuration offers more advance options to further tail the output to your needs,
like naming conventions and aliases.

.. literalinclude:: /_build/config.sample.xml
   :language: xml

.. currentmodule:: xsdata.models.config

.. autosummary::
    :toctree: reference
    :template: dataclass.rst
    :nosignatures:

    GeneratorConfig
    GeneratorOutput

    OutputFormat
    GeneratorConventions
    GeneratorAliases
    StructureStyle
    DocstringStyle
    GeneratorAlias
    NameConvention
    NameCase
